@@ -1,9 +1,9 @@
 import typing as t
 
-from .argparse import ArgParse
+from .argparse import ArgParseExt
 from .defaults import make_config
 
 __all__: t.List[str] = [
-    "ArgParse",
+    "ArgParseExt",
     "make_config",
 ]
